@@ -65,11 +65,13 @@ struct _GdictAppletPrivate
   
   GConfClient *gconf_client;
   guint notify_id;
+  guint font_notify_id;
 
   gchar *database;
   gchar *strategy;
   gchar *source_name;  
   gchar *print_font;
+  gchar *defbox_font;
 
   gchar *word;  
   GdictContext *context;
@@ -80,18 +82,28 @@ struct _GdictAppletPrivate
   GdictSourceLoader *loader;
 
   GtkWidget *box;
+  GtkWidget *toggle;
   GtkWidget *image;
   GtkWidget *entry;
   GtkWidget *window;
+  GtkWidget *frame;
   GtkWidget *defbox;
 
   guint idle_draw_id;
 
   GdkPixbuf *icon;
 
+  gint window_width;
+  gint window_height;
+
   guint is_window_showing : 1;
 };
 
+#define WINDOW_MIN_WIDTH 	300
+#define WINDOW_MIN_HEIGHT 	200
+#define WINDOW_NUM_COLUMNS 	56
+#define WINDOW_NUM_ROWS  	23
+
 G_DEFINE_TYPE (GdictApplet, gdict_applet, PANEL_TYPE_APPLET);
 
 
@@ -147,6 +159,50 @@ set_atk_name_description (GtkWidget  *widget,
   atk_object_set_description (aobj, description);
 }
 
+static void
+set_window_default_size (GdictApplet *applet)
+{
+  GdictAppletPrivate *priv = applet->priv;
+  GtkWidget *widget, *defbox;
+  gint width, height;
+  gint font_size;
+  GdkScreen *screen;
+  gint monitor_num;
+  GtkRequisition req;
+  GdkRectangle monitor;
+
+  if (!priv->window)
+    return;
+  
+  widget = priv->window;
+  defbox = priv->defbox;
+
+  /* Size based on the font size */
+  font_size = pango_font_description_get_size (defbox->style->font_desc);
+  font_size = PANGO_PIXELS (font_size);
+
+  width = font_size * WINDOW_NUM_COLUMNS;
+  height = font_size * WINDOW_NUM_ROWS;
+
+  /* Use at least the requisition size of the window... */
+  gtk_widget_size_request (widget, &req);
+  width = MAX (width, req.width);
+  height = MAX (height, req.height);
+
+  /* ... but make it no larger than the monitor */
+  screen = gtk_widget_get_screen (widget);
+  monitor_num = gdk_screen_get_monitor_at_window (screen, widget->window);
+
+  gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
+
+  width = MIN (width, monitor.width * 3 / 4);
+  height = MIN (height, monitor.height * 3 / 4);
+
+  /* Set size */
+  gtk_widget_set_size_request (priv->frame, width, height);
+
+}
+
 static void
 clear_cb (GtkWidget   *widget,
 	  GdictApplet *applet)
@@ -193,7 +249,7 @@ save_cb (GtkWidget   *widget,
   					NULL);
   gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
   
-  /* default to user's home */
+  /* default to user's $HOME */
   gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dialog), g_get_home_dir ());
   gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), _("Untitled document"));
   
@@ -233,6 +289,30 @@ save_cb (GtkWidget   *widget,
   gtk_widget_destroy (dialog);
 }
 
+static void
+gdict_applet_set_menu_items_sensitive (GdictApplet *applet,
+				       gboolean     is_sensitive)
+{
+  BonoboUIComponent *popup_component;
+  
+  popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
+  if (!BONOBO_IS_UI_COMPONENT (popup_component))
+    return;
+
+  bonobo_ui_component_set_prop (popup_component,
+		  		"/commands/Clear",
+				"sensitive", (is_sensitive ? "1" : "0"),
+				NULL);
+  bonobo_ui_component_set_prop (popup_component,
+		  		"/commands/Print",
+				"sensitive", (is_sensitive ? "1" : "0"),
+				NULL);
+  bonobo_ui_component_set_prop (popup_component,
+		  		"/commands/Save",
+				"sensitive", (is_sensitive ? "1" : "0"),
+				NULL);
+}
+
 static void
 gdict_applet_build_window (GdictApplet *applet)
 {
@@ -241,9 +321,7 @@ gdict_applet_build_window (GdictApplet *applet)
   GtkWidget *frame;
   GtkWidget *vbox;
   GtkWidget *bbox;
-  GtkWidget *clear;
-  GtkWidget *print;
-  GtkWidget *save;
+  GtkWidget *button;
 
   if (!priv->entry)
     {
@@ -252,13 +330,13 @@ gdict_applet_build_window (GdictApplet *applet)
       return;
     }
   
-  window = gtk_aligned_window_new (priv->entry);
-  
+  window = gtk_aligned_window_new (priv->toggle);
+
   frame = gtk_frame_new (NULL);
   gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);
-  gtk_widget_set_size_request (frame, 400, 220);
   gtk_container_add (GTK_CONTAINER (window), frame);
   gtk_widget_show (frame);
+  priv->frame = frame;
   
   vbox = gtk_vbox_new (FALSE, 12);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), 6);
@@ -278,29 +356,49 @@ gdict_applet_build_window (GdictApplet *applet)
   gtk_box_pack_end (GTK_BOX (vbox), bbox, FALSE, FALSE, 0);
   gtk_widget_show (bbox);
   
-  clear = gtk_button_new_from_stock (GTK_STOCK_CLEAR);
-  set_atk_name_description (clear,
+  button = gtk_button_new_from_stock (GTK_STOCK_CLEAR);
+
+  gtk_tooltips_set_tip (priv->tooltips,
+		  	button,
+		  	_("Clear the definitions found"),
+			NULL);
+  set_atk_name_description (button,
 		  	    _("Clear definition"),
 			    _("Clear the text of the definition"));
-  g_signal_connect (clear, "clicked", G_CALLBACK (clear_cb), applet);
-  gtk_box_pack_start (GTK_BOX (bbox), clear, FALSE, FALSE, 0);
-  gtk_widget_show (clear);
+  
+  g_signal_connect (button, "clicked", G_CALLBACK (clear_cb), applet);
+  gtk_box_pack_start (GTK_BOX (bbox), button, FALSE, FALSE, 0);
+  gtk_widget_show (button);
 
-  print = gtk_button_new_from_stock (GTK_STOCK_PRINT);
-  set_atk_name_description (print,
+  button = gtk_button_new_from_stock (GTK_STOCK_PRINT);
+
+  gtk_tooltips_set_tip (priv->tooltips,
+		  	button,
+			_("Print the definitions found"),
+			NULL);
+  set_atk_name_description (button,
 		  	    _("Print definition"),
 			    _("Print the text of the definition"));
-  g_signal_connect (print, "clicked", G_CALLBACK (print_cb), applet);
-  gtk_box_pack_start (GTK_BOX (bbox), print, FALSE, FALSE, 0);
-  gtk_widget_show (print);
+  
+  g_signal_connect (button, "clicked", G_CALLBACK (print_cb), applet);
+  gtk_box_pack_start (GTK_BOX (bbox), button, FALSE, FALSE, 0);
+  gtk_widget_show (button);
 
-  save = gtk_button_new_from_stock (GTK_STOCK_SAVE);
-  set_atk_name_description (save,
+  button = gtk_button_new_from_stock (GTK_STOCK_SAVE);
+  
+  gtk_tooltips_set_tip (priv->tooltips,
+		  	button,
+			_("Save the definitions found"),
+			NULL);
+  set_atk_name_description (button,
 		  	    _("Save definition"),
 			    _("Save the text of the definition to a file"));
-  g_signal_connect (save, "clicked", G_CALLBACK (save_cb), applet);
-  gtk_box_pack_start (GTK_BOX (bbox), save, FALSE, FALSE, 0);
-  gtk_widget_show (save);
+  
+  g_signal_connect (button, "clicked", G_CALLBACK (save_cb), applet);
+  gtk_box_pack_start (GTK_BOX (bbox), button, FALSE, FALSE, 0);
+  gtk_widget_show (button);
+  
+  set_window_default_size (applet);
   
   priv->window = window;
   priv->is_window_showing = FALSE;
@@ -327,17 +425,24 @@ gdict_applet_toggle_window (GdictApplet *applet)
 }
 
 static gboolean
-gdict_applet_button_press_event_cb (GtkWidget      *widget,
-				    GdkEventButton *event,
-				    GdictApplet    *applet)
+gdict_applet_icon_toggled_cb (GtkWidget   *widget,
+			      GdictApplet *applet)
 {
-  if (event->button == 1)
+  GdictAppletPrivate *priv = applet->priv;
+
+  if (!priv->window)
+    gdict_applet_build_window (applet);
+  
+  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget)))
     {
-      gdict_applet_toggle_window (applet); 
-      return TRUE;
+      gtk_widget_show (priv->window);
+      priv->is_window_showing = TRUE;
     }
   else
-    return FALSE;
+    {
+      gtk_widget_hide (priv->window);
+      priv->is_window_showing = FALSE;
+    }
 }
 
 static void
@@ -360,6 +465,22 @@ gdict_applet_entry_activate_cb (GtkWidget   *widget,
   gdict_defbox_lookup (GDICT_DEFBOX (priv->defbox), priv->word);
 }
 
+static gboolean
+gdict_applet_icon_button_press_event_cb (GtkWidget      *widget,
+					 GdkEventButton *event,
+					 GdictApplet    *applet)
+{
+  GdictAppletPrivate *priv = applet->priv;
+  
+  /* we don't want to block the applet's popup menu unless the
+   * user is toggling the button
+   */
+  if (event->button != 1)
+    g_signal_stop_emission_by_name(priv->toggle, "button-press-event");
+
+  return FALSE;
+}
+
 static gboolean
 gdict_applet_entry_button_press_event_cb (GtkWidget      *widget,
 					  GdkEventButton *event,
@@ -375,7 +496,8 @@ gdict_applet_draw (GdictApplet *applet)
 {
   GdictAppletPrivate *priv = applet->priv;
   GtkWidget *box;
-  GtkWidget *event;
+  GtkWidget *hbox;
+  GtkWidget *label;
   gchar *text = NULL;
 
   if (priv->entry)
@@ -399,11 +521,77 @@ gdict_applet_draw (GdictApplet *applet)
   
   gtk_container_add (GTK_CONTAINER (applet), box);
   gtk_widget_show (box);
+
+  /* toggle button */
+  priv->toggle = gtk_toggle_button_new ();
   
+  set_atk_name_description (priv->toggle,
+			    _("Toggle dictionary window"),
+		  	    _("Show or hide the definition window"));
+  gtk_tooltips_set_tip (priv->tooltips,
+		  	priv->toggle,
+		  	_("Click to view the dictionary window"),
+			NULL);
+  
+  gtk_button_set_relief (GTK_BUTTON (priv->toggle),
+		  	 GTK_RELIEF_NONE);
+  g_signal_connect (priv->toggle, "toggled",
+		    G_CALLBACK (gdict_applet_icon_toggled_cb),
+		    applet);
+  g_signal_connect (priv->toggle, "button-press-event",
+		    G_CALLBACK (gdict_applet_icon_button_press_event_cb),
+		    applet);
+  gtk_box_pack_start (GTK_BOX (box), priv->toggle, FALSE, FALSE, 0);
+  gtk_widget_show (priv->toggle);
+
+  hbox = gtk_hbox_new (FALSE, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (hbox), 0);
+  gtk_container_add (GTK_CONTAINER (priv->toggle), hbox);
+  gtk_widget_show (hbox);
+
+  if (priv->icon)
+    {
+      GdkPixbuf *scaled;
+      
+      priv->image = gtk_image_new ();
+      gtk_image_set_pixel_size (GTK_IMAGE (priv->image), priv->size - 10);
+
+      scaled = gdk_pixbuf_scale_simple (priv->icon,
+		      			priv->size - 5,
+					priv->size - 5,
+					GDK_INTERP_BILINEAR);
+      
+      gtk_image_set_from_pixbuf (GTK_IMAGE (priv->image), scaled);
+      g_object_unref (scaled);
+      
+      gtk_box_pack_start (GTK_BOX (hbox), priv->image, FALSE, FALSE, 0);
+      
+      gtk_widget_show (priv->image);
+    }
+  else
+    {
+      priv->image = gtk_image_new ();
+
+      gtk_image_set_pixel_size (GTK_IMAGE (priv->image), priv->size - 10);
+      gtk_image_set_from_stock (GTK_IMAGE (priv->image),
+				GTK_STOCK_MISSING_IMAGE,
+				-1);
+      
+      gtk_box_pack_start (GTK_BOX (hbox), priv->image, FALSE, FALSE, 0);
+      gtk_widget_show (priv->image);
+    }
+
+  /* entry */
   priv->entry = gtk_entry_new ();
+  
   set_atk_name_description (priv->entry,
 		  	    _("Dictionary entry"),
 			    _("Look up words in dictionaries"));
+  gtk_tooltips_set_tip (priv->tooltips,
+		  	priv->entry,
+			_("Type the word you want to look up"),
+			NULL);
+  
   gtk_entry_set_editable (GTK_ENTRY (priv->entry), TRUE);
   gtk_entry_set_width_chars (GTK_ENTRY (priv->entry), 12);
   g_signal_connect (priv->entry, "activate",
@@ -412,7 +600,7 @@ gdict_applet_draw (GdictApplet *applet)
   g_signal_connect (priv->entry, "button-press-event",
 		    G_CALLBACK (gdict_applet_entry_button_press_event_cb),
 		    applet);
-  gtk_box_pack_start (GTK_BOX (box), priv->entry, FALSE, FALSE, 0);
+  gtk_box_pack_end (GTK_BOX (box), priv->entry, FALSE, FALSE, 0);
   gtk_widget_show (priv->entry);
 
   if (text)
@@ -422,42 +610,6 @@ gdict_applet_draw (GdictApplet *applet)
       g_free (text);
     }
   
-  event = gtk_event_box_new ();
-  g_signal_connect (event, "button-press-event",
-  		    G_CALLBACK (gdict_applet_button_press_event_cb), applet);
-  gtk_box_pack_start (GTK_BOX (box), event, FALSE, FALSE, 0);
-  gtk_widget_show (event);
-  
-  if (priv->icon)
-    {
-      GdkPixbuf *scaled;
-      
-      priv->image = gtk_image_new ();
-      gtk_image_set_pixel_size (GTK_IMAGE (priv->image), priv->size);
-
-      scaled = gdk_pixbuf_scale_simple (priv->icon,
-		      			priv->size - 1 , priv->size - 1,
-					GDK_INTERP_BILINEAR);
-      
-      gtk_image_set_from_pixbuf (GTK_IMAGE (priv->image), scaled);
-      g_object_unref (scaled);
-      
-      gtk_container_add (GTK_CONTAINER (event), priv->image);
-      
-      gtk_widget_show (priv->image);
-    }
-  else
-    {
-      g_warning ("No icon defined");
-
-      priv->image = gtk_image_new ();
-
-      gtk_image_set_pixel_size (GTK_IMAGE (priv->image), priv->size);
-      gtk_image_set_from_stock (GTK_IMAGE (priv->image), GTK_STOCK_MISSING_IMAGE, -1);
-      gtk_container_add (GTK_CONTAINER (event), priv->image);
-      gtk_widget_show (priv->image);
-    }
-  
   priv->box = box;
   
   gtk_widget_grab_focus (priv->entry);
@@ -486,36 +638,20 @@ gdict_applet_lookup_start_cb (GdictContext *context,
 
   if (!priv->is_window_showing)
     {
+      gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->toggle), TRUE);
+      
       gtk_widget_show (priv->window);
-
       priv->is_window_showing = TRUE;
     }
+
+  gdict_applet_set_menu_items_sensitive (applet, FALSE);
 }
 
 static void
 gdict_applet_lookup_end_cb (GdictContext *context,
 			    GdictApplet  *applet)
 {
-  BonoboUIComponent *popup_component;
-  
-  /* enable menu items */
-  popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
-  bonobo_ui_component_set_prop (popup_component,
-		  		"/commands/Clear",
-				"sensitive", "1",
-				NULL);
-
-  popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
-  bonobo_ui_component_set_prop (popup_component,
-		  		"/commands/Print",
-				"sensitive", "1",
-				NULL);
-
-  popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
-  bonobo_ui_component_set_prop (popup_component,
-		  		"/commands/Save",
-				"sensitive", "1",
-				NULL);
+  gdict_applet_set_menu_items_sensitive (applet, TRUE);
 }
 
 static void
@@ -524,30 +660,13 @@ gdict_applet_error_cb (GdictContext *context,
 		       GdictApplet  *applet)
 {
   GdictAppletPrivate *priv = applet->priv;
-  BonoboUIComponent *popup_component;
-
-  /* disable menu items */
-  popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
-  bonobo_ui_component_set_prop (popup_component,
-		  		"/commands/Clear",
-				"sensitive", "0",
-				NULL);
-
-  popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
-  bonobo_ui_component_set_prop (popup_component,
-		  		"/commands/Print",
-				"sensitive", "0",
-				NULL);
-
-  popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
-  bonobo_ui_component_set_prop (popup_component,
-		  		"/commands/Save",
-				"sensitive", "0",
-				NULL);
 
   /* force window hide */
   gtk_widget_hide (priv->window);
   priv->is_window_showing = FALSE;
+  
+  /* disable menu items */
+  gdict_applet_set_menu_items_sensitive (applet, FALSE);
 }
 
 static void
@@ -636,7 +755,7 @@ gdict_applet_cmd_help (BonoboUIComponent *component,
   if (err)
     {
       show_error_dialog (NULL,
-      			 _("There was an error displaying help"),
+      			 _("There was an error while displaying help"),
       			 err->message);
       g_error_free (err);
     }
@@ -703,7 +822,7 @@ gdict_applet_size_allocate (GtkWidget    *widget,
     {
       priv->size = new_size;
 
-      gtk_image_set_pixel_size (GTK_IMAGE (priv->image), priv->size);
+      gtk_image_set_pixel_size (GTK_IMAGE (priv->image), priv->size - 10);
 
       /* re-scale the icon, if it was found */
       if (priv->icon)
@@ -711,7 +830,8 @@ gdict_applet_size_allocate (GtkWidget    *widget,
           GdkPixbuf *scaled;
 
 	  scaled = gdk_pixbuf_scale_simple (priv->icon,
-			  		    priv->size - 1, priv->size - 1,
+			  		    priv->size - 5,
+					    priv->size - 5,
 					    GDK_INTERP_BILINEAR);
 	  
 	  gtk_image_set_from_pixbuf (GTK_IMAGE (priv->image), scaled);
@@ -724,6 +844,17 @@ gdict_applet_size_allocate (GtkWidget    *widget,
 		    						 allocation);
 }
 
+static void
+gdict_applet_style_set (GtkWidget *widget,
+			GtkStyle  *old_style)
+{
+  if (GTK_WIDGET_CLASS (gdict_applet_parent_class)->style_set)
+    GTK_WIDGET_CLASS (gdict_applet_parent_class)->style_set (widget,
+		    					     old_style);
+
+  set_window_default_size (GDICT_APPLET (widget));
+}
+
 static void
 gdict_applet_set_database (GdictApplet *applet,
 			   const gchar *database)
@@ -841,6 +972,32 @@ gdict_applet_set_print_font (GdictApplet *applet,
   priv->print_font = g_strdup (print_font);
 }
 
+static void
+gdict_applet_set_defbox_font (GdictApplet *applet,
+			      const gchar *defbox_font)
+{
+  GdictAppletPrivate *priv = applet->priv;
+  
+  if (!defbox_font)
+    defbox_font = gconf_client_get_string (priv->gconf_client,
+		    			   DOCUMENT_FONT_KEY,
+					   NULL);
+
+  if (!defbox_font)
+    defbox_font = GDICT_DEFAULT_DEFBOX_FONT;
+
+  if (priv->defbox_font)
+    g_free (priv->defbox_font);
+
+  priv->defbox_font = g_strdup (defbox_font);
+
+  if (!priv->defbox)
+    return;
+
+  gdict_defbox_set_font_name (GDICT_DEFBOX (priv->defbox),
+			      priv->defbox_font);
+}
+
 static void
 gdict_applet_set_word (GdictApplet *applet,
 		       const gchar *word)
@@ -956,6 +1113,13 @@ gdict_applet_gconf_notify_cb (GConfClient *client,
       else
         gdict_applet_set_strategy (applet, GDICT_DEFAULT_STRATEGY);
     }
+  else if (strcmp (entry->key, DOCUMENT_FONT_KEY) == 0)
+    {
+      if (entry->value && (entry->value->type == GCONF_VALUE_STRING))
+        gdict_applet_set_defbox_font (applet, gconf_value_get_string (entry->value));
+      else
+        gdict_applet_set_defbox_font (applet, GDICT_DEFAULT_DEFBOX_FONT);
+    }
 }
 
 static void
@@ -963,6 +1127,12 @@ gdict_applet_finalize (GObject *object)
 {
   GdictApplet *applet = GDICT_APPLET (object);
   GdictAppletPrivate *priv = applet->priv;
+
+  if (priv->notify_id)
+    gconf_client_notify_remove (priv->gconf_client, priv->notify_id);
+
+  if (priv->font_notify_id)
+    gconf_client_notify_remove (priv->gconf_client, priv->font_notify_id);
   
   if (priv->gconf_client)
     g_object_unref (priv->gconf_client);
@@ -990,6 +1160,7 @@ gdict_applet_finalize (GObject *object)
   
   g_free (priv->source_name);
   g_free (priv->print_font);
+  g_free (priv->defbox_font);
   g_free (priv->word);
   
   G_OBJECT_CLASS (gdict_applet_parent_class)->finalize (object);
@@ -1005,6 +1176,7 @@ gdict_applet_class_init (GdictAppletClass *klass)
   gobject_class->finalize = gdict_applet_finalize;
   
   widget_class->size_allocate = gdict_applet_size_allocate;
+  widget_class->style_set = gdict_applet_style_set;
   
   applet_class->change_background = gdict_applet_change_background;
   applet_class->change_orient = gdict_applet_change_orient;
@@ -1016,28 +1188,36 @@ static void
 gdict_applet_init (GdictApplet *applet)
 {
   GdictAppletPrivate *priv;
-  gchar *loader_path, *data_dir, *icon_file;
-  BonoboUIComponent *popup_component;
+  gchar *data_dir, *icon_file;
   GdkPixbuf *icon;
-  GError *icon_error;
+  GError *icon_error, *gconf_error;
 
   priv = GDICT_APPLET_GET_PRIVATE (applet);
   applet->priv = priv;
       
-  /* create the data directory inside $HOME, if it doesn't exist yet */
   data_dir = g_build_filename (g_get_home_dir (),
   			       ".gnome2",
   			       "gnome-dictionary",
   			       NULL);
 
+  /* create the data directory inside $HOME, if it doesn't exist yet */
   if (g_mkdir (data_dir, 0700) == -1)
     {
       if (errno != EEXIST)
-        g_warning ("Unable to create the data directory '%s'");
+        {
+	  gchar *message;
+
+	  message = g_strdup_printf (_("Unable to create the data directory '%s'"),
+				     data_dir);
+	  
+          show_error_dialog (NULL,
+			     message,
+			     strerror (errno));
+
+	  g_free (message);
+	}
     }
   
-  g_free (data_dir);
-  
   icon_file = g_build_filename (DATADIR,
 		  		"pixmaps",
 				"gnome-dictionary.png",
@@ -1046,8 +1226,9 @@ gdict_applet_init (GdictApplet *applet)
   icon = gdk_pixbuf_new_from_file (icon_file, &icon_error);
   if (icon_error)
     {
-      g_warning (_("Unable to load the application icon: %s"),
-		 icon_error->message);
+      show_error_dialog (NULL,
+			 _("Unable to load the applet icon"),
+			 icon_error->message);
 
       g_error_free (icon_error);
       priv->icon = NULL;
@@ -1067,25 +1248,58 @@ gdict_applet_init (GdictApplet *applet)
   if (!priv->gconf_client)
     priv->gconf_client = gconf_client_get_default ();
   
+  gconf_error = NULL;
   gconf_client_add_dir (priv->gconf_client,
   			GDICT_GCONF_DIR,
   			GCONF_CLIENT_PRELOAD_ONELEVEL,
-  			NULL);
-  gconf_client_notify_add (priv->gconf_client,
-		  	   GDICT_GCONF_DIR,
-			   (GConfClientNotifyFunc) gdict_applet_gconf_notify_cb,
-			   applet, NULL,
-			   NULL);
+  			&gconf_error);
+  if (gconf_error)
+    {
+      show_error_dialog (NULL,
+		         _("Unable to connect to GConf"),
+			 gconf_error->message);
+      
+      g_error_free (gconf_error);
+      gconf_error = NULL;
+    }
+  
+  priv->notify_id = gconf_client_notify_add (priv->gconf_client,
+		  			     GDICT_GCONF_DIR,
+					     gdict_applet_gconf_notify_cb,
+					     applet, NULL,
+					     &gconf_error);
+  if (gconf_error)
+    {
+      show_error_dialog (NULL,
+		         _("Unable to get notification for preferences"),
+			 gconf_error->message);
+
+      g_error_free (gconf_error);
+      gconf_error = NULL;
+    }
+  
+  priv->font_notify_id =  gconf_client_notify_add (priv->gconf_client,
+		  				   DOCUMENT_FONT_KEY,
+						   gdict_applet_gconf_notify_cb,
+						   applet, NULL,
+						   &gconf_error);
+  if (gconf_error)
+    {
+      show_error_dialog (NULL,
+			 _("Unable to get notification for the document font"),
+			 gconf_error->message);
+
+      g_error_free (gconf_error);
+      gconf_error = NULL;
+    }
   
   if (!priv->loader)
     priv->loader = gdict_source_loader_new ();
 
-  loader_path = g_build_filename (g_get_home_dir (),
-                                  ".gnome2",
-                                  "gnome-dictionary",
-                                  NULL);
-  gdict_source_loader_add_search_path (priv->loader, loader_path);
-  g_free (loader_path);
+  /* add our data dir inside $HOME to the loader's search paths */
+  gdict_source_loader_add_search_path (priv->loader, data_dir);
+
+  g_free (data_dir);
 
 #ifndef GDICT_APPLET_STAND_ALONE
   priv->size = panel_applet_get_size (PANEL_APPLET (applet));
@@ -1114,37 +1328,23 @@ gdict_applet_init (GdictApplet *applet)
   g_object_ref (priv->tooltips);
   gtk_object_sink (GTK_OBJECT (priv->tooltips));
 
-  /* disable menu items */
-  popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
-  bonobo_ui_component_set_prop (popup_component,
-		  		"/commands/Clear",
-				"sensitive", "0",
-				NULL);
-
-  popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
-  bonobo_ui_component_set_prop (popup_component,
-		  		"/commands/Print",
-				"sensitive", "0",
-				NULL);
-
-  popup_component = panel_applet_get_popup_component (PANEL_APPLET (applet));
-  bonobo_ui_component_set_prop (popup_component,
-		  		"/commands/Save",
-				"sensitive", "0",
-				NULL);
-
   /* force first draw */
   gdict_applet_draw (applet);
 
+  /* force retrieval of the configuration from GConf */
   gdict_applet_set_source_name (applet, NULL);
+  gdict_applet_set_defbox_font (applet, NULL);
+  gdict_applet_set_print_font (applet, NULL);
 }
 
 #ifndef GDICT_APPLET_STAND_ALONE
 static const BonoboUIVerb gdict_applet_menu_verbs[] =
 {
   BONOBO_UI_UNSAFE_VERB ("LookUp", gdict_applet_cmd_lookup),
+  
   BONOBO_UI_UNSAFE_VERB ("Clear", gdict_applet_cmd_clear),
   BONOBO_UI_UNSAFE_VERB ("Print", gdict_applet_cmd_print),
+  
   BONOBO_UI_UNSAFE_VERB ("Preferences", gdict_applet_cmd_preferences),
   BONOBO_UI_UNSAFE_VERB ("Help", gdict_applet_cmd_help),
   BONOBO_UI_UNSAFE_VERB ("About", gdict_applet_cmd_about),
@@ -1170,6 +1370,9 @@ gdict_applet_factory (PanelApplet *applet,
 					 applet);
 
       gtk_widget_show (GTK_WIDGET (applet));
+
+      /* set the menu items insensitive */
+      gdict_applet_set_menu_items_sensitive (GDICT_APPLET (applet), FALSE);
       
       retval = TRUE;
     }
