@@ -36,8 +36,19 @@
 
 #define APP_NAME _("System Log Viewer")
 
+enum {
+  PROP_0,
+  PROP_DAYS,
+};
+
+enum {
+  LOG_LINE_TEXT = 0,
+  LOG_LINE_POINTER,
+  LOG_LINE_WEIGHT,
+  LOG_LINE_WEIGHT_SET
+};
+
 static GObjectClass *parent_class;
-extern gboolean restoration_complete;
 
 /* Function Prototypes */
 
@@ -66,6 +77,8 @@ static void logview_copy (GtkAction *action, LogviewWindow *logview);
 static void logview_select_all (GtkAction *action, LogviewWindow *logview);
 static Log *logview_find_log_from_name (LogviewWindow *logview, gchar *name);
 
+static void logview_window_get_property	(GObject *object, guint param_id, GValue *value, GParamSpec *pspec);
+
 /* Menus */
 
 static GtkActionEntry entries[] = {
@@ -76,14 +89,14 @@ static GtkActionEntry entries[] = {
 
 	{ "OpenLog", GTK_STOCK_OPEN, N_("_Open..."), "<control>O", N_("Open a log from file"), 
 	  G_CALLBACK (logview_open_log) },
-	{ "CloseLog", GTK_STOCK_CLOSE, N_("Close"), "<control>W", N_("Close this log"), 
+	{ "CloseLog", GTK_STOCK_CLOSE, N_("_Close"), "<control>W", N_("Close this log"), 
 	  G_CALLBACK (logview_close_log) },
 	{ "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q", N_("Quit the log viewer"), 
 	  G_CALLBACK (gtk_main_quit) },
 
-	{ "Copy", GTK_STOCK_COPY, N_("Copy"), "<control>C", N_("Copy the selection"),
+	{ "Copy", GTK_STOCK_COPY, N_("_Copy"), "<control>C", N_("Copy the selection"),
 	  G_CALLBACK (logview_copy) },
-	{ "SelectAll", NULL, N_("Select All"), "<Control>A", N_("Select the entire log"),
+	{ "SelectAll", NULL, N_("Select _All"), "<Control>A", N_("Select the entire log"),
 	  G_CALLBACK (logview_select_all) },
 	{ "Search", GTK_STOCK_FIND, N_("_Filter..."), "<control>F", N_("Filter log"),
 	  G_CALLBACK (logview_search) },
@@ -106,7 +119,7 @@ static GtkActionEntry entries[] = {
 };
 
 static GtkToggleActionEntry toggle_entries[] = {
-    { "ShowStatusBar", NULL, N_("Statusbar"), NULL, N_("Show Status Bar"),
+    { "ShowStatusBar", NULL, N_("_Statusbar"), NULL, N_("Show Status Bar"),
       G_CALLBACK (logview_toggle_statusbar), TRUE },
 	{ "ShowSidebar", NULL, N_("Side _Pane"), "F9", N_("Show Side Pane"), 
 		G_CALLBACK (logview_toggle_sidebar), TRUE },
@@ -170,31 +183,40 @@ int
 logview_count_logs (LogviewWindow *logview)
 {
     g_assert (LOGVIEW_IS_WINDOW (logview));
-    return g_list_length (logview->logs);
+    return g_slist_length (logview->logs);
+}
+
+static void
+logview_store_visible_range (LogviewWindow *logview)
+{
+  GtkTreePath *first, *last;
+  Log *log = logview->curlog;
+  if (log == NULL)
+    return;
+
+  if (log->visible_first)
+    gtk_tree_path_free (log->visible_first);
+
+  if (gtk_tree_view_get_visible_range (GTK_TREE_VIEW (logview->view),
+                                       &first, NULL))
+    log->visible_first = first;
 }
 
 void
 logview_select_log (LogviewWindow *logview, Log *log)
 {
-	g_return_if_fail (LOGVIEW_IS_WINDOW (logview));
-    
-    if (log == NULL) {
-        /* there is no selected log right now */
-        logview->curlog = NULL;
-        logview_menus_set_state (logview);
-        logview_calendar_set_state (logview);
-        log_repaint (logview);
-        logview_update_findbar_visibility (logview);
-        return;
-    }
-	logview->curlog = log;
-	logview_menus_set_state (logview);
+    g_return_if_fail (LOGVIEW_IS_WINDOW (logview));
+  
+    logview_store_visible_range (logview);
+
+    logview->curlog = log;
+    logview_menus_set_state (logview);
+    logview_calendar_set_state (logview);
+    logview_repaint (logview);
     logview_update_findbar_visibility (logview);
-	logview_update_version_bar (logview);
-	logview_calendar_set_state (logview);
-    log->displayed_lines = 0;
-	log_repaint (logview);
-	logview_save_prefs (logview); 
+    
+    logview_update_version_bar (logview);
+    logview_save_prefs (logview); 
     gtk_widget_grab_focus (logview->view);
 } 
 
@@ -206,31 +228,35 @@ logview_add_log_from_name (LogviewWindow *logview, gchar *file)
     g_return_if_fail (LOGVIEW_IS_WINDOW (logview));
     g_return_if_fail (file);
 
-	log = log_open (file, TRUE);
-	if (log != NULL)
-		  logview_add_log (logview, log);
+    log = log_open (file, TRUE);
+    if (log != NULL)
+      logview_add_log (logview, log);
 }
 
 void
 logview_add_logs_from_names (LogviewWindow *logview, GSList *lognames, gchar *selected)
 {
-	GSList *list;
-	Log *log, *curlog = NULL;
-
+    GSList *list;
+    Log *log, *curlog = NULL;
+	
     g_return_if_fail (LOGVIEW_IS_WINDOW (logview));
-    g_return_if_fail (lognames);
 
-	for (list = lognames; list != NULL; list = g_slist_next (list)) {
-        log = log_open (list->data, FALSE);
-        if (log != NULL) {
-            logview_add_log (logview, log);
-            if (g_strncasecmp (log->name, selected, -1)==0)
-                curlog = log;
-        }
+    if (lognames == NULL)
+        return;
+
+    for (list = lognames; list != NULL; list = g_slist_next (list)) {
+      log = log_open (list->data, FALSE);
+      if (log != NULL) {
+	logview_add_log (logview, log);
+	if (selected!=NULL && g_strncasecmp (log->name, selected, -1)==0)
+	  curlog = log;
+      }
     }
         
     if (curlog)
         loglist_select_log (LOG_LIST (logview->loglist), curlog);
+
+    gtk_tree_view_expand_all (GTK_TREE_VIEW (logview->loglist));
 }
 
 void
@@ -252,35 +278,55 @@ logview_menus_set_state (LogviewWindow *logview)
     logview_menu_item_set_state (logview, "/LogviewMenu/FileMenu/MonitorLogs", monitor_active);
     logview_menu_item_set_state (logview, "/LogviewMenu/ViewMenu/ShowCalendar", calendar_active);
     logview_menu_item_set_state (logview, "/LogviewMenu/FileMenu/CloseLog", (log != NULL));
-    logview_menu_item_set_state (logview, "/LogviewMenu/ViewMenu/CollapseAll", (log != NULL));
+    logview_menu_item_set_state (logview, "/LogviewMenu/ViewMenu/CollapseAll", calendar_active);
     logview_menu_item_set_state (logview, "/LogviewMenu/ViewMenu/Search", (log != NULL));
     logview_menu_item_set_state (logview, "/LogviewMenu/EditMenu/Copy", (log != NULL));
     logview_menu_item_set_state (logview, "/LogviewMenu/EditMenu/SelectAll", (log != NULL));
 }
 
 void
-logview_set_window_title (LogviewWindow *window)
+logview_set_window_title (LogviewWindow *logview)
 {
-	gchar *window_title;
-	gchar *logname;
+    gchar *window_title;
+    gchar *logname;
+    Log *log;
 
-    g_assert (LOGVIEW_IS_WINDOW (window));
+    g_assert (LOGVIEW_IS_WINDOW (logview));
 
-	if ((window->curlog != NULL) && (window->curlog->name != NULL)) {
-		if (window->curlog->display_name != NULL)
-			logname = window->curlog->display_name;
-		else
-			logname = window->curlog->name;
-		
-		if (window->curlog->monitored) 
-			window_title = g_strdup_printf (_("%s (monitored) - %s"), logname, APP_NAME);
-		else
-			window_title = g_strdup_printf ("%s - %s", logname, APP_NAME);
-	}
-	else
-		window_title = g_strdup_printf (APP_NAME);
-	gtk_window_set_title (GTK_WINDOW (window), window_title);
-	g_free (window_title);
+    log = logview->curlog;
+    if (log == NULL)
+      return;
+
+    if (log->name != NULL) {
+
+      if (log->display_name != NULL)
+	logname = log->display_name;
+      else
+	logname = log->name;
+      
+      if (log->monitored) 
+	window_title = g_strdup_printf (_("%s (monitored) - %s"), logname, APP_NAME);
+      else
+	window_title = g_strdup_printf ("%s - %s", logname, APP_NAME);
+
+    }
+    else
+      window_title = g_strdup_printf (APP_NAME);
+
+    gtk_window_set_title (GTK_WINDOW (logview), window_title);
+    g_free (window_title);
+}
+
+void
+logview_show_main_content (LogviewWindow *logview)
+{
+  g_return_if_fail (LOGVIEW_IS_WINDOW (logview));
+  gtk_widget_show (logview->calendar);
+  gtk_widget_show (logview->loglist);
+  gtk_widget_show (logview->sidebar);
+  gtk_widget_show (logview->view);
+  gtk_widget_show (logview->hpaned);
+  gtk_widget_show (logview->statusbar);
 }
 
 /* private functions */
@@ -303,22 +349,26 @@ logview_update_findbar_visibility (LogviewWindow *logview)
 static void
 logview_save_prefs (LogviewWindow *logview)
 {
-    GList *list;
+    GSList *list;
     Log *log;
 
     g_return_if_fail (LOGVIEW_IS_WINDOW (logview));
 
-	if (restoration_complete) {
+    if (GTK_WIDGET_VISIBLE (GTK_WIDGET (logview->loglist))) {
         prefs_free_loglist();
-        for (list = g_list_first (logview->logs); list != NULL; list = g_list_next (list)) {
+        for (list = logview->logs; list != NULL; list = g_slist_next (list)) {
             log = list->data;
             prefs_store_log (log->name);
         }
         
-        if (logview->curlog)
-            prefs_store_active_log (logview->curlog->name);
+        if (logview->curlog) {
+	  if (logview->curlog->parent_log)
+            prefs_store_active_log (logview->curlog->parent_log->name);
+	  else
+	    prefs_store_active_log (logview->curlog->name);
+	}
         prefs_store_fontsize (logview->fontsize);
-		prefs_save ();
+	prefs_save ();
     }
 }
 
@@ -330,15 +380,15 @@ logview_destroy (GObject *object, LogviewWindow *logview)
     if (logview->curlog) {
         if (logview->curlog->monitored)
             monitor_stop (logview->curlog);
-        if (!(logview->curlog->display_name))
-            prefs_store_active_log (logview->curlog->name);
-        else
-            prefs_store_active_log (NULL);
     }
 
-    prefs_save ();
+    logview_save_prefs (logview);
     prefs_free_loglist ();
-    gtk_main_quit ();
+
+    if (gtk_main_level() > 0)
+      gtk_main_quit ();
+    else
+      exit (0);
 }
 
 static void
@@ -347,7 +397,7 @@ logview_add_log (LogviewWindow *logview, Log *log)
     g_return_if_fail (LOGVIEW_IS_WINDOW (logview));
     g_return_if_fail (log);
 
-    logview->logs = g_list_append (logview->logs, log);
+    logview->logs = g_slist_append (logview->logs, log);
     monitor_start (log);
     loglist_add_log (LOG_LIST(logview->loglist), log);
     log->window = logview;    
@@ -357,13 +407,13 @@ logview_add_log (LogviewWindow *logview, Log *log)
 static Log *
 logview_find_log_from_name (LogviewWindow *logview, gchar *name)
 {
-  GList *list;
+  GSList *list;
   Log *log;
 
   if (logview == NULL || name == NULL)
       return NULL;
 
-  for (list = logview->logs; list != NULL; list = g_list_next (list)) {
+  for (list = logview->logs; list != NULL; list = g_slist_next (list)) {
     log = list->data;
     if (g_ascii_strncasecmp (log->name, name, 255) == 0) {
       return log;
@@ -420,7 +470,7 @@ logview_close_log (GtkAction *action, LogviewWindow *logview)
     log = logview->curlog;
     logview->curlog = NULL;
 
-    logview->logs = g_list_remove (logview->logs, log);
+    logview->logs = g_slist_remove (logview->logs, log);
     log_close (log);
     loglist_remove_log (LOG_LIST (logview->loglist), log);
 }
@@ -439,14 +489,14 @@ logview_file_selected_cb (GtkWidget *chooser, gint response, LogviewWindow *logv
    f = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser));
 
    if (f != NULL) {
-	   /* Check if the log is not already opened */
-	   GList *list;
+       /* Check if the log is not already opened */
+       GSList *list;
        Log *log, *tl;
-	   for (list = logview->logs; list != NULL; list = g_list_next (list)) {
+	   for (list = logview->logs; list != NULL; list = g_slist_next (list)) {
 		   log = list->data;
 		   if (g_ascii_strncasecmp (log->name, f, 255) == 0) {
-				 loglist_select_log (LOG_LIST (logview->loglist), log);
-			   return;
+		     loglist_select_log (LOG_LIST (logview->loglist), log);
+		     return;
 		   }
 	   }
 
@@ -607,7 +657,7 @@ logview_search (GtkAction *action, LogviewWindow *logview)
 {
     g_assert (LOGVIEW_IS_WINDOW (logview));
     
-	gtk_widget_show (logview->find_bar);
+    gtk_widget_show_all (logview->find_bar);
     logview_findbar_grab_focus (LOGVIEW_FINDBAR (logview->find_bar));
 }
 
@@ -683,7 +733,7 @@ logview_calendar_set_state (LogviewWindow *logview)
 
     if (logview->curlog) {
         if (logview->curlog->days != NULL)
-            calendar_init_data (CALENDAR (logview->calendar), logview->curlog);
+            calendar_init_data (CALENDAR (logview->calendar), logview);
         gtk_widget_set_sensitive (logview->calendar, (logview->curlog->days != NULL));
     } else
         gtk_widget_set_sensitive (logview->calendar, FALSE);
@@ -705,26 +755,26 @@ static gboolean
 window_size_changed_cb (GtkWidget *widget, GdkEventConfigure *event, 
 				 gpointer data)
 {
-	LogviewWindow *window = data;
+    LogviewWindow *logview = LOGVIEW_WINDOW (data);
     
-    g_assert (LOGVIEW_IS_WINDOW (window));
-	prefs_store_window_size (GTK_WIDGET(window));
-	return FALSE;
+    g_assert (LOGVIEW_IS_WINDOW (logview));
+    prefs_store_window_size (GTK_WIDGET(logview));
+    return FALSE;
 }
 
 static void
 logview_window_finalize (GObject *object)
 {
-    LogviewWindow *window = (LogviewWindow *) object;
+    LogviewWindow *logview = LOGVIEW_WINDOW(object);
 
-	g_object_unref (window->ui_manager);
+    g_object_unref (logview->ui_manager);
     parent_class->finalize (object);
 }
 
 static void
-logview_init (LogviewWindow *window)
+logview_init (LogviewWindow *logview)
 {
-   GtkWidget *vbox, *hbox;
+   GtkWidget *vbox;
    GtkTreeStore *tree_store;
    GtkTreeSelection *selection;
    GtkTreeViewColumn *column;
@@ -737,36 +787,35 @@ logview_init (LogviewWindow *window)
    GtkWidget *hpaned;
    GtkWidget *label;
    GtkWidget *main_view;
-   GtkWidget *scrolled;
+   GtkWidget *loglist_scrolled, *scrolled;
    PangoContext *context;
    PangoFontDescription *fontdesc;
    gchar *monospace_font_name;
 
-   gtk_window_set_default_size (GTK_WINDOW (window), prefs_get_width (), prefs_get_height ());
+   gtk_window_set_default_size (GTK_WINDOW (logview), prefs_get_width (), prefs_get_height ());
 
    vbox = gtk_vbox_new (FALSE, 0);
-   gtk_container_add (GTK_CONTAINER (window), vbox);
+   gtk_container_add (GTK_CONTAINER (logview), vbox);
 
    /* Create menus */
    action_group = gtk_action_group_new ("LogviewMenuActions");
    gtk_action_group_set_translation_domain (action_group, NULL);
-   gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), window);
-   gtk_action_group_add_toggle_actions(action_group, toggle_entries, G_N_ELEMENTS (toggle_entries), window);
+   gtk_action_group_add_actions (action_group, entries, G_N_ELEMENTS (entries), logview);
+   gtk_action_group_add_toggle_actions(action_group, toggle_entries, G_N_ELEMENTS (toggle_entries), logview);
 
-   window->ui_manager = gtk_ui_manager_new ();
+   logview->ui_manager = gtk_ui_manager_new ();
 
-   gtk_ui_manager_insert_action_group (window->ui_manager, action_group, 0);
+   gtk_ui_manager_insert_action_group (logview->ui_manager, action_group, 0);
    
-   accel_group = gtk_ui_manager_get_accel_group (window->ui_manager);
-   gtk_window_add_accel_group (GTK_WINDOW (window), accel_group);
+   accel_group = gtk_ui_manager_get_accel_group (logview->ui_manager);
+   gtk_window_add_accel_group (GTK_WINDOW (logview), accel_group);
    
-   if (!gtk_ui_manager_add_ui_from_string (window->ui_manager, ui_description, -1, &error)) {
-	   g_message ("Building menus failed: %s", error->message);
-	   g_error_free (error);
-	   exit (1);
+   if (!gtk_ui_manager_add_ui_from_string (logview->ui_manager, ui_description, -1, &error)) {
+     logview->ui_manager = NULL;
+     return;
    }
    
-   menubar = gtk_ui_manager_get_widget (window->ui_manager, "/LogviewMenu");
+   menubar = gtk_ui_manager_get_widget (logview->ui_manager, "/LogviewMenu");
    gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
 
    /* panes */
@@ -774,23 +823,23 @@ logview_init (LogviewWindow *window)
    gtk_box_pack_start (GTK_BOX (vbox), hpaned, TRUE, TRUE, 0);
 
    /* First pane : sidebar (list of logs + calendar) */
-   window->sidebar = gtk_vbox_new (FALSE, 0);
+   logview->sidebar = gtk_vbox_new (FALSE, 0);
    
-   window->calendar = calendar_new ();
-   calendar_connect (CALENDAR (window->calendar), window);
-   gtk_box_pack_end (GTK_BOX (window->sidebar), GTK_WIDGET(window->calendar), FALSE, FALSE, 0);
+   logview->calendar = calendar_new ();
+   calendar_connect (CALENDAR (logview->calendar), logview);
+   gtk_box_pack_end (GTK_BOX (logview->sidebar), GTK_WIDGET(logview->calendar), FALSE, FALSE, 0);
    
    /* log list */
-   scrolled = gtk_scrolled_window_new (NULL, NULL);
-   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled),
+   loglist_scrolled = gtk_scrolled_window_new (NULL, NULL);
+   gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (loglist_scrolled),
                                    GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
-   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled),
+   gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (loglist_scrolled),
                                         GTK_SHADOW_ETCHED_IN);
-   window->loglist = loglist_new ();
-   gtk_container_add (GTK_CONTAINER (scrolled), window->loglist);
-   gtk_box_pack_start (GTK_BOX (window->sidebar), scrolled, TRUE, TRUE, 0);
-   gtk_paned_pack1 (GTK_PANED (hpaned), window->sidebar, FALSE, FALSE);
-   loglist_connect (LOG_LIST(window->loglist), window);
+   logview->loglist = loglist_new ();
+   gtk_container_add (GTK_CONTAINER (loglist_scrolled), logview->loglist);
+   gtk_box_pack_start (GTK_BOX (logview->sidebar), loglist_scrolled, TRUE, TRUE, 0);
+   gtk_paned_pack1 (GTK_PANED (hpaned), logview->sidebar, FALSE, FALSE);
+   loglist_connect (LOG_LIST(logview->loglist), logview);
 
    /* Second pane : log */
    main_view = gtk_vbox_new (FALSE, 0);
@@ -804,69 +853,88 @@ logview_init (LogviewWindow *window)
    gtk_box_pack_start (GTK_BOX(main_view), scrolled, TRUE, TRUE, 0);
 
    /* Main Tree View */
-   window->view = gtk_tree_view_new ();
-   gtk_tree_view_set_rules_hint (GTK_TREE_VIEW (window->view), TRUE); 
-   gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (window->view), TRUE);
-   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (window->view), FALSE);
+   logview->view = gtk_tree_view_new ();
+   gtk_tree_view_set_fixed_height_mode (GTK_TREE_VIEW (logview->view), TRUE);
+   gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (logview->view), FALSE);
 
    /* Use the desktop monospace font */
    monospace_font_name = prefs_get_monospace ();
-   widget_set_font (GTK_WIDGET (window->view), monospace_font_name);
+   widget_set_font (GTK_WIDGET (logview->view), monospace_font_name);
    g_free (monospace_font_name);
   
    renderer = gtk_cell_renderer_text_new ();
-   column = gtk_tree_view_column_new_with_attributes (NULL, renderer, "text", 0, NULL);
+   column = gtk_tree_view_column_new ();
+   gtk_tree_view_column_pack_start (column, renderer, TRUE);
+   gtk_tree_view_column_set_attributes (column, renderer, 
+                                        "text", LOG_LINE_TEXT, 
+                                        "weight", LOG_LINE_WEIGHT,
+                                        "weight-set", LOG_LINE_WEIGHT_SET,
+                                        NULL);
    gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
-   gtk_tree_view_append_column (GTK_TREE_VIEW (window->view), column);
-
-   window->find_bar = logview_findbar_new ();
-   gtk_box_pack_end (GTK_BOX (main_view), window->find_bar, FALSE, FALSE, 0);
-   logview_findbar_connect (LOGVIEW_FINDBAR (window->find_bar), window);
+   gtk_tree_view_append_column (GTK_TREE_VIEW (logview->view), column);
 
    /* Version selector */
-   window->version_bar = gtk_hbox_new (FALSE, 0);
-   gtk_container_set_border_width (GTK_CONTAINER (window->version_bar), 3);
-   window->version_selector = gtk_combo_box_new_text ();
-   g_signal_connect (G_OBJECT (window->version_selector), "changed",
-                     G_CALLBACK (logview_version_selector_changed), window);
+   logview->version_bar = gtk_hbox_new (FALSE, 0);
+   gtk_container_set_border_width (GTK_CONTAINER (logview->version_bar), 3);
+   logview->version_selector = gtk_combo_box_new_text ();
+   g_signal_connect (G_OBJECT (logview->version_selector), "changed",
+                     G_CALLBACK (logview_version_selector_changed), logview);
    label = gtk_label_new (_("Version: "));
    
-   gtk_box_pack_end (GTK_BOX(window->version_bar), window->version_selector, FALSE, FALSE, 0);
-   gtk_box_pack_end (GTK_BOX(window->version_bar), label, FALSE, FALSE, 0);
-   gtk_box_pack_end (GTK_BOX(main_view), window->version_bar, FALSE, FALSE, 0);
+   gtk_box_pack_end (GTK_BOX(logview->version_bar), logview->version_selector, FALSE, FALSE, 0);
+   gtk_box_pack_end (GTK_BOX(logview->version_bar), label, FALSE, FALSE, 0);
+   gtk_box_pack_end (GTK_BOX(main_view), logview->version_bar, FALSE, FALSE, 0);
    
-   /* Remember the original font size */
-   context = gtk_widget_get_pango_context (window->view);
-   fontdesc = pango_context_get_font_description (context);
-   window->original_fontsize = pango_font_description_get_size (fontdesc) / PANGO_SCALE;
-   window->fontsize = window->original_fontsize;
+   logview->find_bar = logview_findbar_new ();
+   gtk_box_pack_end (GTK_BOX (main_view), logview->find_bar, FALSE, FALSE, 0);
+   logview_findbar_connect (LOGVIEW_FINDBAR (logview->find_bar), logview);
 
-   gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (window->view));
+   /* Remember the original font size */
+   context = gtk_widget_get_pango_context (logview->view);
+   fontdesc = pango_context_get_font_description (context);
+   logview->original_fontsize = pango_font_description_get_size (fontdesc) / PANGO_SCALE;
+   logview->fontsize = logview->original_fontsize;
+
+   gtk_container_add (GTK_CONTAINER (scrolled), GTK_WIDGET (logview->view));
    gtk_widget_show_all (scrolled);
    
-   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (window->view));
+   selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (logview->view));
    gtk_tree_selection_set_mode (selection, GTK_SELECTION_MULTIPLE);
 
    /* Add signal handlers */
    g_signal_connect (G_OBJECT (selection), "changed",
-                     G_CALLBACK (selection_changed_cb), window);
-   g_signal_connect (G_OBJECT (window->view), "row-expanded",
-                     G_CALLBACK (row_toggled_cb), window);
-   g_signal_connect (G_OBJECT (window->view), "row-collapsed",
-                     G_CALLBACK (row_toggled_cb), window);
-   g_signal_connect (G_OBJECT (window), "configure_event",
-                     G_CALLBACK (window_size_changed_cb), window);
+                     G_CALLBACK (selection_changed_cb), logview);
+   g_signal_connect (G_OBJECT (logview->view), "row-expanded",
+                     G_CALLBACK (row_toggled_cb), logview);
+   g_signal_connect (G_OBJECT (logview->view), "row-collapsed",
+                     G_CALLBACK (row_toggled_cb), logview);
+   g_signal_connect (G_OBJECT (logview), "configure_event",
+                     G_CALLBACK (window_size_changed_cb), logview);
 
    /* Status area at bottom */
-   hbox = gtk_hbox_new (FALSE, 0);   
-   window->statusbar = gtk_statusbar_new ();
-   gtk_box_pack_start (GTK_BOX (hbox), window->statusbar, TRUE, TRUE, 0);
+   logview->statusbar = gtk_statusbar_new ();
+   gtk_box_pack_start (GTK_BOX (vbox), logview->statusbar, FALSE, FALSE, 0);
 
-   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+   gtk_widget_show (menubar);
+   gtk_widget_show (loglist_scrolled);
+   gtk_widget_show (main_view);
+   gtk_widget_show (vbox);
+   logview->hpaned = hpaned;
+}
 
-   gtk_widget_show_all (vbox);
-   gtk_widget_hide (window->find_bar);
-   gtk_widget_hide (window->version_bar);
+static void
+logview_window_get_property (GObject *object, guint param_id, GValue *value, GParamSpec *pspec)
+{
+  LogviewWindow *logview = LOGVIEW_WINDOW (object);
+  
+  switch (param_id) {
+  case PROP_DAYS:
+    g_value_set_pointer (value, logview->curlog->days);
+    break;
+  default:
+    G_OBJECT_WARN_INVALID_PROPERTY_ID (object, param_id, pspec);
+    break;
+  }
 }
 
 static void
@@ -875,7 +943,14 @@ logview_window_class_init (LogviewWindowClass *klass)
 	GObjectClass *object_class = (GObjectClass *) klass;
 
 	object_class->finalize = logview_window_finalize;
+	object_class->get_property = logview_window_get_property;
 	parent_class = g_type_class_peek_parent (klass);
+
+	g_object_class_install_property (object_class, PROP_DAYS,
+					 g_param_spec_pointer ("days",
+					 _("Days"),
+					 _("Pointer towards a GSList of days for the current log."),
+					 (G_PARAM_READABLE)));
 }
 
 GType
@@ -910,12 +985,12 @@ logview_window_new ()
 
    window = g_object_new (LOGVIEW_TYPE_WINDOW, NULL);
    logview = LOGVIEW_WINDOW (window);
+   if (logview->ui_manager == NULL)
+     return NULL;
 
    logview->logs = NULL;
    logview->clipboard = gtk_clipboard_get_for_display (gtk_widget_get_display (window),
 							     GDK_SELECTION_CLIPBOARD);
-
-   /* FIXME : we need to listen to this key, not just read it. */
    gtk_ui_manager_set_add_tearoffs (logview->ui_manager, 
                                     prefs_get_have_tearoff ());
 
